idrlnet.pde\_op package
=======================

.. automodule:: idrlnet.pde_op
   :members:
   :undoc-members:
   :show-inheritance:

Submodules
----------

idrlnet.pde\_op.equations module
--------------------------------

.. automodule:: idrlnet.pde_op.equations
   :members:
   :undoc-members:
   :show-inheritance:

idrlnet.pde\_op.operator module
-------------------------------

.. automodule:: idrlnet.pde_op.operator
   :members:
   :undoc-members:
   :show-inheritance:
